# encoding: utf-8
module Nokaya
  class Workers

    attr_accessor :options

    def initialize options
      @options = options
    end

    def save object
      if object.urls.empty?
        abort(Status.no_can_do)
      else
        save_images(object)
      end
    end

    def save_images object
      save_tuples(object)
    end

    def save_tuples object
      begin
        tuples = object.urls.zip(object.filenames)
        Dir.mkdir(object.path) unless Dir.exist?(object.path)
        tuples.each do |url, name|
          f = File.new("#{object.path}/#{name}", "wb")
           f.puts(get_image(url))
          f.close
        end
      rescue Errno::EACCES
        abort(Status.no_access)
      end
    end

    def get_image img_link
      begin
        open(img_link).read
      rescue SocketError, SystemCallError
        abort(Status.no_cnx)
      rescue Exception
        abort(Status.no_can_do)
      end
    end

    def path
      if options['output']
        options['output']
      else
        Dir.home + "/Downloads"
      end
    end

    def sanitize str
      reg = /[~:-;,?!\'&`^=+<>*%()\/"“”’°£$€.…]/
      str.downcase.strip.gsub(reg, '_').split(' ').join('_').squeeze('_') unless str.nil? || str.empty?
    end

    def timed
      t = Time.now
      "#{t.year}#{'%02d' % t.month}#{'%02d' % t.day}#{'%02d' % t.hour}#{'%02d' % t.min}#{'%02d' % t.sec}"
    end

  end
end
